Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1081)

Unified Diff: Source/core/rendering/RenderMenuList.cpp

Issue 940373003: Rename RenderText to LayoutText (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/rendering/RenderMenuList.h ('k') | Source/core/rendering/RenderText.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/rendering/RenderMenuList.cpp
diff --git a/Source/core/rendering/RenderMenuList.cpp b/Source/core/rendering/RenderMenuList.cpp
index ff4b7d8d929d2084012ac5fdcf740aaa443e59c2..7e42cd3570d2eedf730487caf431000d45dff3fc 100644
--- a/Source/core/rendering/RenderMenuList.cpp
+++ b/Source/core/rendering/RenderMenuList.cpp
@@ -289,10 +289,10 @@ void RenderMenuList::setText(const String& s)
DeprecatedDisableModifyRenderTreeStructureAsserts disabler;
if (m_buttonText)
m_buttonText->destroy();
- m_buttonText = new RenderText(&document(), s.impl());
+ m_buttonText = new LayoutText(&document(), s.impl());
m_buttonText->setStyle(style());
// We need to set the text explicitly though it was specified in the
// constructor because RenderText doesn't refer to the text
// specified in the constructor in a case of re-transforming.
m_buttonText->setText(s.impl(), true);
addChild(m_buttonText);
@@ -289,10 +289,10 @@ void RenderMenuList::setText(const String& s)
m_buttonText->setStyle(style());
// We need to set the text explicitly though it was specified in the
- // constructor because RenderText doesn't refer to the text
+ // constructor because LayoutText doesn't refer to the text
// specified in the constructor in a case of re-transforming.
m_buttonText->setText(s.impl(), true);
« no previous file with comments | « Source/core/rendering/RenderMenuList.h ('k') | Source/core/rendering/RenderText.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698